cumulusci.tasks.apex package
============================

.. automodule:: cumulusci.tasks.apex
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

cumulusci.tasks.apex.anon module
--------------------------------

.. automodule:: cumulusci.tasks.apex.anon
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.apex.batch module
---------------------------------

.. automodule:: cumulusci.tasks.apex.batch
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.apex.testrunner module
--------------------------------------

.. automodule:: cumulusci.tasks.apex.testrunner
   :members:
   :undoc-members:
   :show-inheritance:

